@@ -30,8 +30,8 @@ def isSlience(Filename =None):
     with open(wav2pcm(Filename), 'rb') as ref:
         indata = ref.read()
     ins = np.frombuffer(indata, dtype=np.int16)
-    print(ins)
-    print(get_rms(ins))
+    dBrmsValue = 20*math.log(get_rms(ins)/32767)
+    return dBrmsValue
     pass
 
 
